@@ -18,7 +18,9 @@ has extjs_app_title             => ( is => 'ro', isa => Str, default => sub { re
 
 # TODO fix ExtJS overrides version
 around run => sub ( $orig, $self, $req ) {
-    if ( $req->{path_tail} && $req->{path_tail} ne 'index.html' ) {
+
+    # if path tail is not empty - fallback to the original method
+    if ( $req->{path_tail} ) {
         $self->$orig($req);
 
         return;
@@ -106,7 +108,7 @@ around run => sub ( $orig, $self, $req ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    1 | 40                   | RegularExpressions::ProhibitEnumeratedClasses - Use named character classes ([a-z] vs. [[:lower:]])            |
+## |    1 | 42                   | RegularExpressions::ProhibitEnumeratedClasses - Use named character classes ([a-z] vs. [[:lower:]])            |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
